Fixup refs to 'bst fetch'

Now that 'bst fetch' is obsolete, change guidance to refer to the
replacement 'bst source fetch' instead.
diff --git a/buildstream/_loader/loader.py b/buildstream/_loader/loader.py
index 25c2630..13761fb 100644
--- a/buildstream/_loader/loader.py
+++ b/buildstream/_loader/loader.py
@@ -557,7 +557,7 @@
                         ticker(filename, 'Fetching subproject from {} source'.format(source.get_kind()))
                     source._fetch(sources[0:idx])
                 else:
-                    detail = "Try fetching the project with `bst fetch {}`".format(filename)
+                    detail = "Try fetching the project with `bst source fetch {}`".format(filename)
                     raise LoadError(LoadErrorReason.SUBPROJECT_FETCH_NEEDED,
                                     "Subproject fetch needed for junction: {}".format(filename),
                                     detail=detail)
diff --git a/buildstream/_pipeline.py b/buildstream/_pipeline.py
index 8f6c788..7cf36f5 100644
--- a/buildstream/_pipeline.py
+++ b/buildstream/_pipeline.py
@@ -406,7 +406,7 @@
                     if source._get_consistency() != Consistency.CACHED:
                         detail += "    {}\n".format(source)
                 detail += '\n'
-            detail += "Try fetching these elements first with `bst fetch`,\n" + \
+            detail += "Try fetching these elements first with `bst source fetch`,\n" + \
                       "or run this command with `--fetch` option\n"
 
             raise PipelineError("Uncached sources", detail=detail, reason="uncached-sources")
diff --git a/buildstream/plugins/elements/junction.py b/buildstream/plugins/elements/junction.py
index a2ae3b6..2550e1f 100644
--- a/buildstream/plugins/elements/junction.py
+++ b/buildstream/plugins/elements/junction.py
@@ -93,7 +93,7 @@
 
 .. code::
 
-   bst fetch junction.bst
+   bst source fetch junction.bst
 
 Other commands such as ``bst build`` implicitly fetch junction sources.
 
@@ -146,7 +146,7 @@
 
     def get_unique_key(self):
         # Junctions do not produce artifacts. get_unique_key() implementation
         # is still required for `bst fetch`.
         return 1
 
     def configure_sandbox(self, sandbox):
@@ -146,7 +146,7 @@
     def get_unique_key(self):
         # Junctions do not produce artifacts. get_unique_key() implementation
-        # is still required for `bst fetch`.
+        # is still required for `bst source fetch`.
         return 1
 